/*-----------------------------------------------------------------
LOG
    GEM - Graphics Environment for Multimedia

    A cone

    Copyright (c) 1997-1998 Mark Danks. mdanks@cybermed.ucsd.edu
    For information on usage and redistribution, and for a DISCLAIMER OF ALL
    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.

-----------------------------------------------------------------*/

#ifndef INCLUDE_CONE_H_
#define INCLUDE_CONE_H_

#include "Base/GemGluObj.h"

/*-----------------------------------------------------------------
-------------------------------------------------------------------
CLASS
    cone
    
    Creates a cone

KEYWORD
    geo
    
DESCRIPTION

-----------------------------------------------------------------*/
class cone : public GemGluObj
{
    CPPEXTERN_HEADER(cone, GemGluObj)

    public:

	    //////////
	    // Constructor
    	cone(t_floatarg size);
    	
    protected:
    	
    	//////////
    	// Destructor
    	virtual ~cone();

    	//////////
    	// Do the rendering
    	virtual void 	render(GemState *state);
};

#endif	// for header file
